==> h2o-java-rest-bindings-3.8.2.2-sources.jar: water/bindings/pojos/ModelMetricsClusteringV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
public class ModelMetricsClusteringV3 extends ModelMetricsBase {
    /** Within Cluster Sum of Square Error */
    public double tot_withinss;

    /** Total Sum of Square Error to Grand Mean */
    public double totss;

    /** Between Cluster Sum of Square Error */
    public double betweenss;

    /** Centroid Statistics */
    public TwoDimTableV3 centroid_stats;

    /* INHERITED: The model used for this scoring run. 
     * public ModelKeyV3 model;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
     * public long model_checksum;
     */

    /* INHERITED: The frame used for this scoring run. 
     * public FrameKeyV3 frame;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
     * public long frame_checksum;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
     * public String description;
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
     * public ModelCategory model_category;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
     * public long scoring_time;
     */

    /* INHERITED: Predictions Frame. 
     * public FrameV3 predictions;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
     * public double MSE;
     */

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.8-sources.jar: water/bindings/pojos/ModelMetricsClusteringV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsClusteringV3 extends ModelMetricsBase {
    /** Within Cluster Sum of Square Error */
    public double tot_withinss;

    /** Total Sum of Square Error to Grand Mean */
    public double totss;

    /** Between Cluster Sum of Square Error */
    public double betweenss;

    /** Centroid Statistics */
    public TwoDimTableV3 centroid_stats;

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsClusteringV3() {
        tot_withinss = 0.0;
        totss = 0.0;
        betweenss = 0.0;
        centroid_stats = null;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
